==> zio-aws-groundstation_3-5.17.166.2-sources.jar: zio/aws/groundstation/model/CreateMissionProfileResponse.scala <==
package zio.aws.groundstation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateMissionProfileResponse(
    missionProfileId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.CreateMissionProfileResponse = {
    import CreateMissionProfileResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.CreateMissionProfileResponse
      .builder()
      .optionallyWith(missionProfileId.map(value => value: java.lang.String))(
        _.missionProfileId
      )
      .build()
  }
  def asReadOnly
      : zio.aws.groundstation.model.CreateMissionProfileResponse.ReadOnly =
    zio.aws.groundstation.model.CreateMissionProfileResponse
      .wrap(buildAwsValue())
}
object CreateMissionProfileResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.CreateMissionProfileResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.CreateMissionProfileResponse =
      zio.aws.groundstation.model
        .CreateMissionProfileResponse(missionProfileId.map(value => value))
    def missionProfileId: Optional[String]
    def getMissionProfileId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("missionProfileId", missionProfileId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.CreateMissionProfileResponse
  ) extends zio.aws.groundstation.model.CreateMissionProfileResponse.ReadOnly {
    override val missionProfileId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.missionProfileId())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.CreateMissionProfileResponse
  ): zio.aws.groundstation.model.CreateMissionProfileResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-groundstation_3-7.21.15.4-sources.jar: zio/aws/groundstation/model/CreateMissionProfileResponse.scala <==
package zio.aws.groundstation.model
import zio.aws.groundstation.model.primitives.Uuid
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateMissionProfileResponse(
    missionProfileId: Optional[Uuid] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.CreateMissionProfileResponse = {
    import CreateMissionProfileResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.CreateMissionProfileResponse
      .builder()
      .optionallyWith(
        missionProfileId.map(value => Uuid.unwrap(value): java.lang.String)
      )(_.missionProfileId)
      .build()
  }
  def asReadOnly
      : zio.aws.groundstation.model.CreateMissionProfileResponse.ReadOnly =
    zio.aws.groundstation.model.CreateMissionProfileResponse
      .wrap(buildAwsValue())
}
object CreateMissionProfileResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.CreateMissionProfileResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.CreateMissionProfileResponse =
      zio.aws.groundstation.model
        .CreateMissionProfileResponse(missionProfileId.map(value => value))
    def missionProfileId: Optional[Uuid]
    def getMissionProfileId: ZIO[Any, AwsError, Uuid] =
      AwsError.unwrapOptionField("missionProfileId", missionProfileId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.CreateMissionProfileResponse
  ) extends zio.aws.groundstation.model.CreateMissionProfileResponse.ReadOnly {
    override val missionProfileId: Optional[Uuid] = zio.aws.core.internal
      .optionalFromNullable(impl.missionProfileId())
      .map(value => zio.aws.groundstation.model.primitives.Uuid(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.CreateMissionProfileResponse
  ): zio.aws.groundstation.model.CreateMissionProfileResponse.ReadOnly =
    new Wrapper(impl)
}
